==> opensaml-xacml-impl-3.4.6-sources.jar: org/opensaml/xacml/policy/impl/IdReferenceTypeUnmarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xacml.policy.impl;

import net.shibboleth.utilities.java.support.primitive.StringSupport;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.core.xml.schema.impl.XSStringUnmarshaller;
import org.opensaml.xacml.policy.IdReferenceType;
import org.w3c.dom.Attr;

/**
 * Unmarshaller for {@link IdReferenceType}.
 */
public class IdReferenceTypeUnmarshaller extends XSStringUnmarshaller {
    
    /** {@inheritDoc} */
    @Override
    protected void processAttribute(final XMLObject xmlObject, final Attr attribute) throws UnmarshallingException {
        final IdReferenceType idReferenceType = (IdReferenceType)xmlObject;
     
        if(attribute.getLocalName().equals(IdReferenceType.EARLIEST_VERSION_ATTRIB_NAME)){           
            idReferenceType.setEarliestVersion(StringSupport.trimOrNull(attribute.getValue()));
        }else if(attribute.getLocalName().equals(IdReferenceType.LATEST_VERSION_ATTRIB_NAME)){           
            idReferenceType.setLatestVersion(StringSupport.trimOrNull(attribute.getValue()));
        }else if(attribute.getLocalName().equals(IdReferenceType.VERSION_ATTRIB_NAME)){           
            idReferenceType.setVersion(StringSupport.trimOrNull(attribute.getValue()));
        } else {
            super.processAttribute(xmlObject, attribute);
        }
    }

}

==> opensaml-xacml-impl-5.1.3-sources.jar: org/opensaml/xacml/policy/impl/IdReferenceTypeUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xacml.policy.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.core.xml.schema.impl.XSStringUnmarshaller;
import org.opensaml.xacml.policy.IdReferenceType;
import org.w3c.dom.Attr;

import net.shibboleth.shared.primitive.StringSupport;

/**
 * Unmarshaller for {@link IdReferenceType}.
 */
public class IdReferenceTypeUnmarshaller extends XSStringUnmarshaller {
    
    /** {@inheritDoc} */
    @Override
    protected void processAttribute(final XMLObject xmlObject, final Attr attribute) throws UnmarshallingException {
        final IdReferenceType idReferenceType = (IdReferenceType)xmlObject;
     
        if(attribute.getLocalName().equals(IdReferenceType.EARLIEST_VERSION_ATTRIB_NAME)){           
            idReferenceType.setEarliestVersion(StringSupport.trimOrNull(attribute.getValue()));
        }else if(attribute.getLocalName().equals(IdReferenceType.LATEST_VERSION_ATTRIB_NAME)){           
            idReferenceType.setLatestVersion(StringSupport.trimOrNull(attribute.getValue()));
        }else if(attribute.getLocalName().equals(IdReferenceType.VERSION_ATTRIB_NAME)){           
            idReferenceType.setVersion(StringSupport.trimOrNull(attribute.getValue()));
        } else {
            super.processAttribute(xmlObject, attribute);
        }
    }

}
